==> zio-aws-ecs_2.13-5.17.116.1-sources.jar: zio/aws/ecs/model/PutClusterCapacityProvidersResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class PutClusterCapacityProvidersResponse(
    cluster: Option[zio.aws.ecs.model.Cluster] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse = {
    import PutClusterCapacityProvidersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse
      .builder()
      .optionallyWith(cluster.map(value => value.buildAwsValue()))(_.cluster)
      .build()
  }
  def asReadOnly
      : zio.aws.ecs.model.PutClusterCapacityProvidersResponse.ReadOnly =
    zio.aws.ecs.model.PutClusterCapacityProvidersResponse.wrap(buildAwsValue())
}
object PutClusterCapacityProvidersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.PutClusterCapacityProvidersResponse =
      zio.aws.ecs.model.PutClusterCapacityProvidersResponse(
        cluster.map(value => value.asEditable)
      )
    def cluster: Option[zio.aws.ecs.model.Cluster.ReadOnly]
    def getCluster: ZIO[Any, AwsError, zio.aws.ecs.model.Cluster.ReadOnly] =
      AwsError.unwrapOptionField("cluster", cluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse
  ) extends zio.aws.ecs.model.PutClusterCapacityProvidersResponse.ReadOnly {
    override val cluster: Option[zio.aws.ecs.model.Cluster.ReadOnly] = scala
      .Option(impl.cluster())
      .map(value => zio.aws.ecs.model.Cluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse
  ): zio.aws.ecs.model.PutClusterCapacityProvidersResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ecs_2.13-5.19.31.2-sources.jar: zio/aws/ecs/model/PutClusterCapacityProvidersResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PutClusterCapacityProvidersResponse(
    cluster: Optional[zio.aws.ecs.model.Cluster] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse = {
    import PutClusterCapacityProvidersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse
      .builder()
      .optionallyWith(cluster.map(value => value.buildAwsValue()))(_.cluster)
      .build()
  }
  def asReadOnly
      : zio.aws.ecs.model.PutClusterCapacityProvidersResponse.ReadOnly =
    zio.aws.ecs.model.PutClusterCapacityProvidersResponse.wrap(buildAwsValue())
}
object PutClusterCapacityProvidersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.PutClusterCapacityProvidersResponse =
      zio.aws.ecs.model.PutClusterCapacityProvidersResponse(
        cluster.map(value => value.asEditable)
      )
    def cluster: Optional[zio.aws.ecs.model.Cluster.ReadOnly]
    def getCluster: ZIO[Any, AwsError, zio.aws.ecs.model.Cluster.ReadOnly] =
      AwsError.unwrapOptionField("cluster", cluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse
  ) extends zio.aws.ecs.model.PutClusterCapacityProvidersResponse.ReadOnly {
    override val cluster: Optional[zio.aws.ecs.model.Cluster.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cluster())
        .map(value => zio.aws.ecs.model.Cluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.PutClusterCapacityProvidersResponse
  ): zio.aws.ecs.model.PutClusterCapacityProvidersResponse.ReadOnly =
    new Wrapper(impl)
}
